--[[---------------------------------------------------------------------------

Copyright (c) 2008-2017 by K. Scott Piel 
All Rights Reserved

E-mail: < kscottpiel@gmail.com >

This file is part of nUI.

The author no longer develops or directly supports this addon and has released it
into the public domain under the Creative Commons Attribution-NonCommercial 3.0 
Unported license - a copy of which is included in this distribution. This source
may not be distributed without said license.
	   
nUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the enclosed license for more details.
	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS  "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT  LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
OF THE POSSIBILITY OF SUCH DAMAGE.

--]]---------------------------------------------------------------------------

local addonName, addon = ...

if not nUI_Profile then nUI_Profile = {}; end;

nUI_Profile.nUI_ChocolateBar = {};
nUI_Profile.nUI_BazookaBar = {};

local ChocolateBar = nil;
local Bazooka = nil;
local defaultMinimapSetting = false;

-------------------------------------------------------------------------------------
-- Bazooka (OKAY)

local function DetectBazooka_Bars()
	nUI_TopBarsLocator:ClearAllPoints();
	if (Bazooka.TopAnchor) then
    	nUI_TopBarsLocator:SetPoint("BOTTOM", Bazooka.TopAnchor, "BOTTOM", 0, 0);
    else
		nUI_TopBarsLocator:SetPoint("BOTTOM", UIParent, "TOP", 0, 0);
	end
	
	nUI_BottomBarsLocator:ClearAllPoints();
	if (Bazooka.BottomAnchor) then
    	nUI_BottomBarsLocator:SetPoint("TOP", Bazooka.BottomAnchor, "TOP", 0, 0);
    else
		nUI_BottomBarsLocator:SetPoint("TOP", UIParent, "BOTTOM", 0, 0);
	end
end

-------------------------------------------------------------------------------------
-- ChocolateBar (OKAY)

local function DetectChocolateBar_Bars()
	local temptop = {};
	local tempbottom = {};
	local chocolateBars = {};
	local ChocolateLowestTopBar = nil;
	local ChocolateHighestBottomBar = nil;

	-- Get the Bars from ChocolateBar
	temptop = {}
	tempbottom = {}
	
	chocolateBars = ChocolateBar:GetBars();
	for k,v in pairs(chocolateBars) do
		local settings = v.settings
		local index = settings.index
		if settings.align == "top" then
			table.insert(temptop,{v,index})
		else
			table.insert(tempbottom,{v,index})
		end
	end
	table.sort(temptop, function(a,b)return a[2] < b[2] end)
	table.sort(tempbottom, function(a,b)return a[2] < b[2] end)

	for i, v in ipairs(temptop) do
		ChocolateLowestTopBar = v[1]
	end
	
	for i, v in ipairs(tempbottom) do
		ChocolateHighestBottomBar = v[1]
	end

	-- ChocolateLowestTopBar is located at the top of the screen
	nUI_TopBarsLocator:ClearAllPoints();
	
	if ChocolateLowestTopBar and ChocolateLowestTopBar:GetAlpha() > 0 then 
		nUI_TopBarsLocator:SetPoint( "BOTTOM", ChocolateLowestTopBar, "BOTTOM", 0, 0 );
	else
		nUI_TopBarsLocator:SetPoint( "BOTTOM", UIParent, "TOP", 0, 0 );
	end
	
	-- ChocolateHighestBottomBar is located at the bottom of the screen
	nUI_BottomBarsLocator:ClearAllPoints();	
	
	if ChocolateHighestBottomBar and ChocolateHighestBottomBar:GetAlpha() > 0 then
		nUI_BottomBarsLocator:SetPoint( "TOP", ChocolateHighestBottomBar, "TOP", 0, 0 );
	else
		nUI_BottomBarsLocator:SetPoint( "TOP", UIParent, "BOTTOM", 0, 0 );
	end	
end

-------------------------------------------------------------------------------------
-- Titan Panel (OK)

local function DetectTitanPanel_Bars()
    if not TitanUtils_GetBarAnchors then return end
    
    local topAnchor, bottomAnchor = TitanUtils_GetBarAnchors();

    nUI_TopBarsLocator:ClearAllPoints();
    nUI_TopBarsLocator:SetPoint( "TOPLEFT", topAnchor, "BOTTOMLEFT", 0, 0 );

    nUI_BottomBarsLocator:ClearAllPoints();
    nUI_BottomBarsLocator:SetPoint( "BOTTOMLEFT", bottomAnchor, "TOPLEFT", 0, 0 );
end

-------------------------------------------------------------------------------------
-- Docking Station (Top/Bottom okay, Center is not but unable to change here)

local function DetectDockingStation_Bars()
end

-------------------------------------------------------------------------------------
-- Events
local addonLoaded = false
local bazookaLoaded = false
local titanLoaded = false
local chocolateLoaded = false
local dockingLoaded = false

local function onEvent( self, event, arg1 )
    if event == "ADDON_LOADED" then
        if arg1 == addonName then addonLoaded = true end
        if arg1 == "Titan" then titanLoaded = true end
        if arg1 == "Bazooka" then bazookaLoaded = true end
        if arg1 == "ChocolateBar" then chocolateLoaded = true end
        if arg1 == "DockingStation" then dockingLoaded = true end
        if addonLoaded then
            titanLoaded = IsAddOnLoaded("Titan") 
            bazookaLoaded = IsAddOnLoaded("Bazooka")
            chocolateLoaded = IsAddOnLoaded("ChocolateBar")
            self:RegisterEvent( "VARIABLES_LOADED" );
            self:RegisterEvent( "PLAYER_LOGIN" );
            self:RegisterEvent( "PLAYER_ENTERING_WORLD" );
            self:RegisterEvent( "PLAYER_LOGOUT" );
        end
            
    elseif event == "VARIABLES_LOADED" then
        if titanLoaded  then
            defaultMinimapSetting = TitanUtils_GetMinimapAdjust()
            TitanUtils_SetMinimapAdjust( false );
        end
    elseif event == "PLAYER_LOGIN" then
        if bazookaLoaded then
            Bazooka = LibStub("AceAddon-3.0"):GetAddon("Bazooka");
            if Bazooka then
                DetectBazooka_Bars();
            end
        end
    elseif event == "PLAYER_ENTERING_WORLD" then
        if chocolateLoaded then
            ChocolateBar = LibStub("AceAddon-3.0"):GetAddon("ChocolateBar");
            if ChocolateBar then
                ChocolateBar.nUI_AnchorBars	= ChocolateBar.AnchorBars;
                ChocolateBar.AnchorBars = function()
                    ChocolateBar:nUI_AnchorBars();
                    DetectChocolateBar_Bars();
                end;
                DetectChocolateBar_Bars();
            end	
        end
        if titanLoaded then
            DetectTitanPanel_Bars()
        end
        if dockingLoaded then
            DetectDockingStation_Bars()
        end
    elseif event == "PLAYER_LOGOUT" then
        if titanLoaded then
            TitanUtils_SetMinimapAdjust( defaultMinimapSetting );
        end
    end
end

-------------------------------------------------------------------------------------
-- Events Frame

local frame = CreateFrame( "Frame", "nUI_BrokerDisplayEvents", WorldFrame )
frame:SetScript( "OnEvent", onEvent );
frame:RegisterEvent( "ADDON_LOADED" );
